@@ -451,9 +451,10 @@ class KameleoonClient:
             if visitor_code in self.data:
                 if not self.data[visitor_code]:
                     self.data[visitor_code] = []
-                self.data[visitor_code].append(args[0])
+                self.data[visitor_code] += list(args)
             else:
-                self.data[visitor_code] = [args[0], ]
+                self.data[visitor_code] = [*args]
+        self.logger.debug("Activate feature request")
 
     def track_conversion(self, visitor_code: str, goal_id: int, revenue: float = 0.0) -> None:
         """
@@ -1176,7 +1177,8 @@ class KameleoonClient:
         if visitor_code:
             try:
                 data[visitor_code] = [
-                    data_instance for data_instance in self.data[visitor_code] if not data_instance.sent
+                    data_instance
+                    for data_instance in self.data[visitor_code] if not data_instance.sent
                 ]
                 if not data[visitor_code]:
                     data = {}
